import $ from 'jquery';

/**
 * Dodaje proizvod u košaricu.
 *
 * @param data
 * @param $button
 * @param $pane
 */
function addToCart(data, $button, $pane)
{
    $button.removeClass('added');
    $button.addClass('loading');

    $(document.body).trigger('adding_to_cart', [$button, data]);
    data.action = 'ep_add_to_cart';

    $.post(ep_webshop.ajaxurl, data, function(response) {
        $(document.body).trigger('added_to_cart', [response.fragments, response.cart_hash]);
        $pane.html($(response.replace).html());
    });
}

/**
 * Dodaje jednostavan proizvod u košaricu.
 *
 * @param e
 */
function addToCartSimple(e)
{
    e.preventDefault();

    let $button = $(this),
        $form = $button.closest('form'),
        $pane = $form.closest('.ajax-pane'),
        $quantity = $form.find('input.qty');

    let productId = parseInt($button.val()),
        data = {
            type: 'simple',
            products: {}
        };

    data.products[productId] = parseFloat($quantity.val());

    addToCart(data, $button, $pane);
}

/**
 * Dodaje grupirani proizvod u košaricu.
 *
 * @param e
 */
function addToCartGrouped(e)
{
    e.preventDefault();

    let $button = $(this),
        $form = $button.closest('form'),
        $pane = $form.closest('.ajax-pane'),
        $table = $form.find('table.group_table'),
        $rows = $table.find('tr');

    let groupedProductId = parseInt($button.val()),
        data = {
            type: 'grouped',
            groupedProductId: groupedProductId,
            products: {}
        };

    $rows.each(function(index, row) {
        let $row = $(row),
            $quantity = $row.find('input.qty'),
            productId = parseInt($row.data('product-id')),
            quantity = parseFloat($quantity.val());

        if (quantity > 0) {
            data.products[productId] = quantity;
        }
    });

    addToCart(data, $button, $pane);
}

/**
 * Dodaje varijabilni proizvod u košaricu.
 *
 * @param e
 */
function addToCartVariable(e)
{
    e.preventDefault();

    let $button = $(this),
        $form = $button.closest('form'),
        $attributes = $form.find('table.variations select'),
        $pane = $form.closest('.ajax-pane'),
        $quantity = $form.find('input.qty');

    let variableProductId = parseInt($form.data('product-id')),
        data = {
            type: 'variable',
            variableProductId: variableProductId,
            quantity: parseFloat($quantity.val()),
            attributes: {}
        };

    $attributes.each(function(index, attribute) {
        let $attribute = $(attribute),
            value = $attribute.val();

        if (value.length > 0) {
            data.attributes[$attribute.attr('name')] = value;
        }
    });

    if (data.quantity > 0 && Object.keys(data.attributes).length > 0) {
        addToCart(data, $button, $pane);
    }
}

$(document)
    .on('click', 'button.ajax-add-to-cart.simple', addToCartSimple)
    .on('click', 'button.ajax-add-to-cart.grouped', addToCartGrouped)
    .on('click', 'button.ajax-add-to-cart.variable', addToCartVariable);