<?php
namespace Ep\Core;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\Log\Logger;
use Zend\Log\Writer\Stream;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class LogFactory
 *
 * @package Ep\Core
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class LoggerFactory implements FactoryInterface
{

	/**
	 * Create an object
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$logOutput = 'php://output';

		if (function_exists('wp_get_upload_dir') && function_exists('get_option')) {
			$uploadDir = wp_get_upload_dir();
			$logOutputDir = sprintf('%s/log', $uploadDir['basedir']);

			if (!is_dir($logOutputDir)) {
				mkdir($logOutputDir, 0755, true);
			}

			$logOutput = sprintf('%s/ep.log', $logOutputDir);
		}

		$writer = new Stream($logOutput);
		$logger = new Logger();
		$logger->addWriter($writer);

		return $logger;
	}
}