<?php
namespace Ep\Form\Helper;
use Zend\Form\Element\Checkbox;
use Zend\Form\Element\Hidden;
use Zend\Form\ElementInterface;

/**
 * Rederira kontrolu elementa.
 *
 * @package Ep\Form\Helper
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class FormControl extends AbstractFormHelper
{
	/**
	 * FormElement helper.
	 *
	 * @var FormElement
	 */
	protected $formElement;

	/**
	 * FormElementErrors helper.
	 *
	 * @var FormElementErrors
	 */
	protected $formElementErrors;

	/**
	 * Vraća FormElement helper
	 *
	 * @return FormElement
	 */
	protected function getFormElementHelper()
	{
		if (null === $this->formElement) {
			$this->formElement = method_exists($this->view, 'plugin')
				? $this->view->plugin('formElement')
				: new FormElement();
		}

		return $this->formElement;
	}

	/**
	 * Vraća FormElementErrors helper.
	 *
	 * @return FormElementErrors
	 */
	protected function getFormElementErrorsHelper()
	{
		if (null === $this->formElementErrors) {
			$this->formElementErrors = method_exists($this->view, 'plugin')
				? $this->view->plugin('formElementErrors')
				: new FormElementErrors();
		}

		return $this->formElementErrors;
	}

	/**
	 * Renderira kontrolu.
	 *
	 * @param ElementInterface|null $element Element.
	 *
	 * @return FormControl|string
	 */
	public function __invoke(ElementInterface $element = null)
	{
		if (null === $element) {
			return $this;
		}

		return $this->render($element);
	}

	/**
	 * Renderira kontrolu.
	 *
	 * @param ElementInterface $element Element.
	 *
	 * @return string
	 */
	public function render(ElementInterface $element)
	{
		$formElement = $this->getFormElementHelper();
		$formElementErrors = $this->getFormElementErrorsHelper();

		$control = $formElement($element);

		if ($element instanceof Hidden) {
			return $control;
		}

		if (count($element->getMessages())) {
			$control .= "\n" . $formElementErrors($element);
		}

		if (!$element instanceof Checkbox) {
			if ($description = $element->getOption('description')) {
				$control .= sprintf('<small class="form-text">%s</small>', $description);
			}
		}

		return sprintf('<div class="form-control-group">%s</div>', $control);
	}
}