<?php
namespace Ep\Form\Helper;

use Indigo\Html\Attribute\CssClassAwareInterface;
use Indigo\Html\Element as HtmlElement;
use Zend\Filter\Word\CamelCaseToDash;
use Zend\Form\Element\Button;
use Zend\Form\Element\Hidden;
use Zend\Form\ElementInterface;

/**
 * Class FormGroup
 *
 * @package Ep\Form\Helper
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class FormGroup extends AbstractFormHelper
{
	/** @var FormLabel */
	protected $formLabel;

	/** @var FormControl */
	protected $formControl;

	/**
	 * Vraća FormLabel helper.
	 *
	 * @return FormLabel
	 */
	protected function getFormLabelHelper()
	{
		if (null === $this->formLabel) {
			$this->formLabel = method_exists($this->view, 'plugin')
				? $this->view->plugin('formLabel')
				: new FormLabel();
		}

		return $this->formLabel;
	}

	/**
	 * Vraća FormControl helper.
	 *
	 * @return FormControl
	 */
	protected function getFormControlHelper()
	{
		if (null === $this->formControl) {
			$this->formControl = method_exists($this->view, 'plugin')
				? $this->view->plugin('formControl')
				: new FormControl();
		}

		return $this->formControl;
	}

	/**
	 * Renderira grupu.
	 *
	 * @param ElementInterface|null $element    Element čiju grupu renderiramo.
	 * @param array                 $attributes Atributi grupe.
	 *
	 * @return FormGroup|string
	 */
	public function __invoke(ElementInterface $element = null, array $attributes = [])
	{
		if (null === $element) {
			return $this;
		}

		return $this->render($element, $attributes);
	}

	/**
	 * Renderira grupu.
	 *
	 * @param ElementInterface $element    Element čiju grupu renderiramo.
	 * @param array            $attributes Atributi grupe.
	 *
	 * @return string
	 */
	public function render(ElementInterface $element, array $attributes = [])
	{
		$formLabel = $this->getFormLabelHelper();
		$formControl = $this->getFormControlHelper();

		$group = new HtmlElement('div', $attributes);
		$group->addClass('form-group', true);

		if ($group_class = $element->getOption('group_class')) {
			$group->addClass(is_array($group_class) ? implode(' ', $group_class) : $group_class);
		}

		$element_class = explode('\\', get_class($element));
		$filter = new CamelCaseToDash();

		$group->addClass(sprintf('form-group-%s', strtolower($filter->filter(end($element_class)))));

		if (count($element->getMessages())) {
			$group->addClass('has-danger');

			if ($element instanceof CssClassAwareInterface) {
				$element->addClass('form-control-danger');
			}
		}

		if ($element->getLabel()
		    && !$element instanceof Button
		    && !$element instanceof Hidden
		) {
			$label = $formLabel($element);
		} else {
			$label = '';
		}

		$control = $formControl->render($element);

		if ($element instanceof Hidden) {
			return $control;
		}

		$control = $label . "\n" . $control;
		$group->setContent($control);

		return $this->getHtmlElementHelper()->render($group);
	}
}