<?php
namespace Ep\WooCommerce;

use Ep\Core\AbstractFactory;

/**
 * Class ConfigProvider
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ConfigProvider
{
	public function __invoke()
	{
		return [
			'dependencies' => $this->getDependencyConfig(),

			'wordpress' => [
				'services' => [
					'WooCommerceAutoMenu',
					'WooCommerceCart',
					'WooCommerceCoupons',
					'WooCommerceHideCart',
					'WooCommerceOrders',
					'WooCommerceProducts',
					'WooCommerceRegistration',
					'WooCommerceRemover',
					'WooCommerceReports',
					'WooCommerceTemplates',
					// Ajax
					'WooCommerceAjaxAddToCart',
					// View
					'WooCommerceViewAddToCart',
				],
			],
		];
	}

	public function getDependencyConfig()
	{
		return [
			'aliases' => [
				'WooCommerceAutoMenu' => AutoMenu::class,
				'WooCommerceCart' => CartService::class,
				'WooCommerceCoupons' => CouponService::class,
				'WooCommerceHideCart' => HideCart::class,
				'WooCommerceOrders' => OrderService::class,
				'WooCommerceProducts' => ProductService::class,
				'WooCommerceRegistration' => RegistrationService::class,
				'WooCommerceRemover' => WooCommerceRemover::class,
				'WooCommerceReports' => ReportService::class,
				'WooCommerceTemplates' => TemplateService::class,
				// Ajax
				'WooCommerceAjaxAddToCart' => Ajax\AddToCart::class,
				// View
				'WooCommerceViewAddToCart' => View\AddToCart::class
			],

            'factories' => [
                AutoMenu::class => AbstractFactory::class,
                CartService::class => AbstractFactory::class,
                CouponService::class => AbstractFactory::class,
                HideCart::class => AbstractFactory::class,
                OrderService::class => AbstractFactory::class,
                ProductService::class => AbstractFactory::class,
                RegistrationService::class => AbstractFactory::class,
                WooCommerceRemover::class => AbstractFactory::class,
                ReportService::class => AbstractFactory::class,
                TemplateService::class => AbstractFactory::class,
                // Ajax
                Ajax\AddToCart::class => AbstractFactory::class,
                // View
                View\AddToCart::class => AbstractFactory::class,
            ],
		];
	}
}