<?php
namespace Ep\WordPress\Formcraft;

use Ep\WordPress\Service\AbstractWordPressService;
use Psr\Container\ContainerInterface;

/**
 * Class FileDownloadAddon
 *
 * @package Ep\Formcraft
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class FileDownloadAddon extends AbstractWordPressService
{
    protected $formId;

	public function __construct(ContainerInterface $container)
	{
		parent::__construct($container);
		$this->download();

        add_action('formcraft_addon_init', function() {
            register_formcraft_addon([$this, 'renderAddon'], 0, 'Preuzimanje Datoteka', 'EpFileUploadController');
        });

        add_action('formcraft_addon_scripts', function() {
            wp_enqueue_script('ep-fc-addon-filedownload', EP_WEBSHOP_URL . '/formcraft-addon.js');
        });

        add_action('formcraft_before_save', function($content) {
            $this->formId = $content['Form ID'];
        });

        add_action('formcraft_after_save', [$this, 'onFormSave'], 10, 4);
	}

	protected function download()
    {
        session_start();

        if (isset($_GET['ep_download']) && !empty($_GET['ep_download'])) {
            $downloadKey = trim($_GET['ep_download']);
            if (isset($_SESSION['ep_downloads'][$downloadKey])) {
                $file = $_SESSION['ep_downloads'][$downloadKey];
                unset($_SESSION['ep_downloads'][$downloadKey]);

                header('Content-Type: application/octet-stream');
                header(sprintf('Content-Disposition: attachment; filename="%s"', basename($file)));
                readfile($file);
                exit;
            }
        }
    }

	/**
	 * Renderira postavke u adminu.
	 */
	public function renderAddon()
	{
		wp_enqueue_media();
        $fileId = null;

		?>
        <div  style="margin: 0 10%; width: 80%; padding-top: 20px;">
            <label for="download_link_text">Tekst linka za preuzimanje</label>
            <input type="text" style="100%" id="download_link_text" placeholder="Download" ng-model="Addons.PreuzimanjeDatoteka.download_link_text">
        </div>

		<div style="margin: 0 10% 20px; width: 80%; padding-top: 20px;">
			<div id="select_file_label">
                <?php
                if (($formId = intval($_GET['id'] ?? 0)) > 0) {
                    $settings = formcraft_get_addon_data('PreuzimanjeDatoteka', (string) $formId);
                    $fileId = isset($settings['file_to_download_id']) && !empty($settings['file_to_download_id'])
                        ? intval($settings['file_to_download_id'])
                        : null;

                    if ($fileId) {
                        $file = get_attached_file($fileId);
                        echo esc_html(basename($file));
                    }
                }
                ?>
            </div>

			<input id="select_file_button" type="button" class="button" value="Odaberite datoteku">
			<input type="text" style="display: none;" id="file_to_download_id" ng-model="Addons.PreuzimanjeDatoteka.file_to_download_id">
		</div>
		<?php

		add_action('admin_footer', function() use ($fileId) {
			?>
			<script>
				jQuery(document).ready(function($) {
					var file_frame;
					var wp_media_post_id = wp.media.model.settings.post.id;
					var $input = $('#file_to_download_id');
                    var set_to_post_id = parseInt('<?= $fileId; ?>');


					jQuery('#select_file_button').on('click', function(e) {
					    e.preventDefault();

					    if (file_frame) {

                        } else {
                            wp.media.model.settings.post.id = set_to_post_id;
                        }

					    file_frame = wp.media.frames.file_frame = wp.media({
						    title: 'Odaberite datoteku za preuzimanje',
						    button: {
						        text: 'Koristi ovu datoteku'
						    },
						    multiple: false
					    });

					    file_frame.on('select', function() {
						    attachment = file_frame.state().get('selection').first().toJSON();
						    $('#select_file_label').html(attachment.filename);
						    $('#file_to_download_id').val(attachment.id).change();
					    });

					    file_frame.open();
					});
				});
			</script>
			<?php
		});
	}

	public function onFormSave($template, $meta, $content, $integrations)
    {
        if (!$this->formId) {
            return;
        }

        $settings = formcraft_get_addon_data('PreuzimanjeDatoteka', $this->formId);
        $this->formId = null;

        if (isset($settings['file_to_download_id']) && !empty($settings['file_to_download_id'])) {
	        $downloadKey = md5(rand() . serialize($content));
	        $fileId = intval($settings['file_to_download_id']);
	        $file = get_attached_file($fileId);

	        if (!isset($_SESSION['ep_downloads'])) {
	            $_SESSION['ep_downloads'] = [];
            }

            $_SESSION['ep_downloads'][$downloadKey] = $file;

	        global $fc_final_response;
	        $text = isset($settings['download_link_text']) && !empty($settings['download_link_text']) ? esc_html($settings['download_link_text']) : 'Download';
	        $url = rtrim(get_option('home'), '/') . '?ep_download=' . $downloadKey;
	        $fc_final_response['success'] = sprintf('<a href="%s">%s</a>', $url, $text);
        }
    }
}