<?php
namespace Ep\WordPress;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu WordPressManagera
 *
 * @package Ep\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class WordPressManagerFactory implements FactoryInterface
{
	/**
	 * Stvara objekt
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$config = $container->get('config');
		$wpConfig = $config['wordpress'] ?? [];

		$manager = new WordPressManager();
		$services = apply_filters('ep/config/wordpress_services', $wpConfig['services'] ?? []);

		if (is_admin()) {
			$services = array_merge($services, apply_filters('ep/config/wordpress_admin_services', $wpConfig['admin_services'] ?? []));
		}

		foreach ($services as $name) {
			$service = $container->get($name);
			$manager->addService($service);
		}

		return $manager;
	}
}