<?php
namespace EpTest\Form;

use Ep\InputFilter\Factory;
use Ep\InputFilter\InputFilter;
use Ep\Validator\DisableableValidatorChain;
use EpTest\IntegrationTestCase;

/**
 * Class IntegrationTest
 *
 * @package EpTest\Form
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class IntegrationTest extends IntegrationTestCase
{
	/**
	 * Kada formu generiramo iz konfiguracije, moramo koristiti našu Factory klasu za inpute.
	 */
	public function testAbstractFormFactoryUsesEpInputFilterFactory()
	{
		$smtpForm = $this->getForm('settings-smtp');
		$formFactory = $smtpForm->getFormFactory();
		$inputFilterFactory = $formFactory->getInputFilterFactory();

		$this->assertInstanceOf(Factory::class, $inputFilterFactory);
	}

	/**
	 * Kada kreiramo input_filter iz specifikacije, filter mora biti naše klase.
	 */
	public function testAbstractFormFactoryUsesEpInputFilterByDefault()
	{
		$smtpForm = $this->getForm('settings-smtp');
		$inputFilter = $smtpForm->getInputFilter();

		$this->assertInstanceOf(InputFilter::class, $inputFilter);
	}

	/**
	 * base_uri element ove forme je tipa Url koji implementira InputProviderInterface.
	 * AbstractFormFactory treba mergeat specifikaciju iz polja s onom iz konfiguracije.
	 */
	public function testAbstractFormFactoryWillMergeInputSpecs()
	{
		$gathForm = $this->getForm('settings-gath');
		$inputFilter = $gathForm->getInputFilter();
		$baseUri = $inputFilter->get('base_uri');
		$validatorChain = $baseUri->getValidatorChain();

		$this->assertInstanceOf(DisableableValidatorChain::class, $validatorChain);
	}
}