<?php
namespace EpTest\Gath\Hydrator;

use DateTime;
use Ep\Gath\Entity\Product;
use Ep\Gath\Entity\ProductBrand;
use Ep\Gath\Entity\ProductShippingClass;
use EpTest\IntegrationTestCase;

/**
 * Class ProductHydratorTest
 *
 * @package EpTest\Gath\Hydrator
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ProductHydratorTest extends IntegrationTestCase
{
	public function testCanHydrateObject()
	{
		$data = [
			'id' => 123456,
			'sku' => 'product_sku',
			'name' => 'product_name',
			'date_modified' => '2018-01-22 12:45:12.780',
			'featured' => true,
			'tax_classHR' => 'standard',
			'tax_class' => '',
			'wsbrandno' => 30,
			'wsartno' => 'tecdoc_art',
			'Brands' => [[
				'BrandId' => 8857,
			]],
			'ShippingClass' => [[
				'ShippingClassId' => 9567,
			]],
			'Images' => [[
				'url' => 'image_1',
			], [
				'url' => 'image_2',
			]]
		];

		$hydrator = $this->getHydrator(Product::class);
		/** @var Product $product */
		$product = $hydrator->hydrate($data, new Product());

		$this->assertEquals(123456, $product->getId());
		$this->assertEquals('product_sku', $product->getSku());
		$this->assertEquals('product_name', $product->getName());
		$this->assertInstanceOf(DateTime::class, $product->getDateModified());
		$this->assertEquals('2018-01-22 12:45:12', $product->getDateModified()->format('Y-m-d H:i:s'));
		$this->assertTrue($product->isFeatured());
		$this->assertEquals('standard', $product->getTaxClass());
		$this->assertEquals(30, $product->getTecdocBrandNo());
		$this->assertEquals('tecdoc_art', $product->getTecdocArticleNo());
		$this->assertTrue($product->hasBrand());
		$this->assertInstanceOf(ProductBrand::class, $product->getBrand());
		$this->assertEquals(8857, $product->getBrandId());
		$this->assertTrue($product->hasShippingClass());
		$this->assertInstanceOf(ProductShippingClass::class, $product->getShippingClass());
		$this->assertEquals(9567, $product->getShippingClassId());
		$this->assertTrue($product->hasImages());
		$this->assertCount(2, $product->getImages());
		$this->assertEquals('image_1', $product->getImages()[0]->getPath());
		$this->assertEquals('image_2', $product->getImages()[1]->getPath());
	}
}