<?php
namespace EpTest\Validator;

use Ep\Validator\DisableableValidatorChain;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Zend\Validator\AbstractValidator;
use Zend\Validator\NotEmpty;
use Zend\Validator\ValidatorInterface;

/**
 * Class DisableableValidatorChainTest
 *
 * @package EpTest\Validator
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class DisableableValidatorChainTest extends TestCase
{
	/**
	 * Ako svi uvjeti nisu zadovoljeni, validator uvijek vraća true.
	 */
	public function testValidatorChainAlwaysReturnsTrueWhenNotActive()
	{
		$chain = new DisableableValidatorChain([
			'name' => 'field',
			'value' => 'value',
		]);

		$chain->attachByName(NotEmpty::class);
		$result = $chain->isValid('', ['field' => 'invalid']);

		$this->assertTrue($result);
	}

	/**
	 * Ako su svi uvjeti zadovoljeni, validator chain će validirati vrijednost.
	 */
	public function testValidatorChainWillValidateIfActive()
	{
		$chain = new DisableableValidatorChain([
			'name' => 'field',
			'value' => 'value',
		]);

		/** @var ValidatorInterface|MockObject $validator */
		$validator = $this->createPartialMock(AbstractValidator::class, ['isValid']);
		$validator->expects($this->once())
				 ->method('isValid')
				 ->willReturn(false);

		$chain->attach($validator);
		$result = $chain->isValid('', ['field' => 'value']);

		$this->assertFalse($result);
	}
}